@@ -1,6 +1,6 @@
 package Catmandu::SRU;
 
-our $VERSION = '0.429';
+our $VERSION = '0.430';
 
 =head1 NAME
 
@@ -9,7 +9,7 @@ Catmandu::SRU - Catmandu module for working with SRU data
 =begin markdown
 
 # STATUS
-[![Build Status](https://travis-ci.org/LibreCat/Catmandu-SRU.svg?branch=master)](https://travis-ci.org/LibreCat/Catmandu-SRU)
+[![Build Status](https://travis-ci.com/LibreCat/Catmandu-SRU.svg?branch=master)](https://travis-ci.com/LibreCat/Catmandu-SRU)
 [![Coverage](https://coveralls.io/repos/LibreCat/Catmandu-SRU/badge.png?branch=master)](https://coveralls.io/r/LibreCat/Catmandu-SRU)
 [![CPANTS kwalitee](http://cpants.cpanauthors.org/dist/Catmandu-SRU.png)](http://cpants.cpanauthors.org/dist/Catmandu-SRU)
 
